@@ -22,7 +22,7 @@ The dialog for customizing remote control settings.
 import dbus, logging, gobject, gtk
 
 from gettext                         import gettext as _
-from gnome_lirc_properties           import backend, config, lirc, model, net
+from gnome_lirc_properties           import backend, config, lirc, model
 from gnome_lirc_properties.ui.common import show_message, thread_callback
 from StringIO                        import StringIO
 from time                            import time
@@ -35,7 +35,7 @@ class CustomConfiguration(object):
                      lirc.KeyCodes.get_default_commands()]),
         value_type=gobject.TYPE_STRING)
 
-    def __init__(self, glade_xml):
+    def __init__(self, builder):
         self.__remote = None
 
         # irrecord drivers:
@@ -47,33 +47,32 @@ class CustomConfiguration(object):
         self.__learning_row = None
 
         # setup widgets
-        self.__setup_ui(glade_xml)
+        self.__setup_ui(builder)
 
     # pylint: disable-msg=W0201
-    def __setup_ui(self, glade_xml):
+    def __setup_ui(self, builder):
         '''Initialize widgets.'''
 
-        self.__ui = glade_xml
-        self.__ui.signal_autoconnect(self)
+        self.__ui = builder
+        self.__ui.connect_signals(self)
 
         # lookup major widgets:
-        self.__dialog   = self.__ui.get_widget('custom_configuration')
-        self.__notebook = self.__ui.get_widget('notebook')
+        self.__dialog   = self.__ui.get_object('custom_configuration')
+        self.__notebook = self.__ui.get_object('notebook')
 
         # lookup buttons:
-        self.__button_ok            = self.__ui.get_widget('button_ok')
-        self.__button_upload        = self.__ui.get_widget('button_upload')
-        self.__button_detect_basics = self.__ui.get_widget('button_detect_basics')
-        self.__button_keys_learn    = self.__ui.get_widget('button_keys_learn')
-        self.__button_keys_remove   = self.__ui.get_widget('button_keys_remove')
-        self.__button_keys_clear    = self.__ui.get_widget('button_keys_clear')
-        self.__button_keys_add      = self.__ui.get_widget('button_keys_add')
+        self.__button_ok            = self.__ui.get_object('button_ok')
+        self.__button_detect_basics = self.__ui.get_object('button_detect_basics')
+        self.__button_keys_learn    = self.__ui.get_object('button_keys_learn')
+        self.__button_keys_remove   = self.__ui.get_object('button_keys_remove')
+        self.__button_keys_clear    = self.__ui.get_object('button_keys_clear')
+        self.__button_keys_add      = self.__ui.get_object('button_keys_add')
 
         # setup model page:
-        self.__entry_vendor      = self.__ui.get_widget('entry_vendor')
-        self.__entry_product     = self.__ui.get_widget('entry_product')
-        self.__entry_contributor = self.__ui.get_widget('entry_contributor')
-        self.__usage_hint        = self.__ui.get_widget('usage_hint')
+        self.__entry_vendor      = self.__ui.get_object('entry_vendor')
+        self.__entry_product     = self.__ui.get_object('entry_product')
+        self.__entry_contributor = self.__ui.get_object('entry_contributor')
+        self.__usage_hint        = self.__ui.get_object('usage_hint')
 
         size_group = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
         size_group.add_widget(self.__entry_vendor)
@@ -83,9 +82,6 @@ class CustomConfiguration(object):
         self.__setup_basics()
         self.__setup_keys()
 
-        # apply "secondary" child property: for some reason libglade ignores it
-        self.__dialog.action_area.set_child_secondary(self.__button_upload, True)
-
         # apply stock icon to learn button
         image = gtk.image_new_from_stock(gtk.STOCK_MEDIA_RECORD,
                                          gtk.ICON_SIZE_BUTTON)
@@ -95,9 +91,9 @@ class CustomConfiguration(object):
     def __setup_basics(self):
         '''Initialize widgets of the "Basics" page.'''
 
-        self.__page_basics               = self.__ui.get_widget('page_basics')
-        self.__treeview_basics           = self.__ui.get_widget('treeview_basics')
-        self.__progressbar_detect_basics = self.__ui.get_widget('progressbar_detect_basics')
+        self.__page_basics               = self.__ui.get_object('page_basics')
+        self.__treeview_basics           = self.__ui.get_object('treeview_basics')
+        self.__progressbar_detect_basics = self.__ui.get_object('progressbar_detect_basics')
 
         treeview_columns = (
             gtk.TreeViewColumn(_('Property'), gtk.CellRendererText(), text=0),
@@ -114,11 +110,11 @@ class CustomConfiguration(object):
     def __setup_keys(self):
         '''Initialize widgets of the "Keys" page.'''
 
-        self.__page_keys       = self.__ui.get_widget('page_keys')
-        self.__treeview_keys   = self.__ui.get_widget('treeview_keys')
-        self.__hbuttonbox_keys = self.__ui.get_widget('hbuttonbox_keys')
-        self.__label_keys_hint = self.__ui.get_widget('label_keys_hint')
-        self.__image_keys_hint = self.__ui.get_widget('image_keys_hint')
+        self.__page_keys       = self.__ui.get_object('page_keys')
+        self.__treeview_keys   = self.__ui.get_object('treeview_keys')
+        self.__hbuttonbox_keys = self.__ui.get_object('hbuttonbox_keys')
+        self.__label_keys_hint = self.__ui.get_object('label_keys_hint')
+        self.__image_keys_hint = self.__ui.get_object('image_keys_hint')
 
         self.__keys_learning_hint = _(
             '<b>Learning new key code.</b>\n'
@@ -334,6 +330,7 @@ class CustomConfiguration(object):
                 self.__learning_driver.Release()
 
             except dbus.DBusException, ex:
+                logging.error('Error running learning driver Release')
                 logging.error(ex)
 
             try:
@@ -341,6 +338,7 @@ class CustomConfiguration(object):
                 backend.get_service().ManageLircDaemon('start')
 
             except dbus.DBusException, ex:
+                logging.error('Error restarting LIRC')
                 logging.error(ex)
 
             self.__learning_driver = None
@@ -363,62 +361,6 @@ class CustomConfiguration(object):
         '''Handle activation of row in the "keys" tree view.'''
         self.__start_learning(path)
 
-    def _on_button_upload_clicked(self, button):
-        '''Handle the "Upload" button's "clicked" signal.'''
-
-        def configuration_problem(message):
-            '''
-            Informs the user about configuration file problems,
-            and ask the user for accption or rejection.
-            '''
-
-            response_buttons = (
-                (gtk.RESPONSE_ACCEPT, _('_Upload Configuration')),
-                (gtk.RESPONSE_REJECT, gtk.STOCK_CANCEL),
-            )
-
-            message = '%s %s' % (message, _('Do you really want to upload this configuration?'))
-
-            return (gtk.RESPONSE_ACCEPT != show_message(
-                    self.__dialog, _('Configuration Problems'),
-                    message, buttons=response_buttons))
-
-        def on_upload_finished(message):
-            '''Informs the user about succeeding uploads.'''
-
-            show_message(self.__dialog, _('Upload Succeeded'),
-                         message, message_type=gtk.MESSAGE_INFO)
-            self.__dialog.set_sensitive(True)
-
-        def on_upload_failure(message):
-            '''Informs the user about upload failures.'''
-
-            show_message(self.__dialog, _('Upload Failed'), message)
-            self.__dialog.set_sensitive(True)
-
-        keys_model = self.__treeview_keys.get_model()
-
-        if 0 == keys_model.count_keys(lirc.KeyCodeCategory.DEFAULT):
-            if configuration_problem(_('This configuration has no keys for the default ' +
-                                       'namespace. Most applications won\'t be able to ' +
-                                       'use this configuration.')):
-                return
-
-        elif 0 != keys_model.count_keys(lirc.KeyCodeCategory.CUSTOM):
-            if configuration_problem(_('Some keys in this configuration have names ' +
-                                       'which do not belong to any standardized namespace.' +
-                                       'Most applications won\'t be able to use those keys.')):
-                return
-
-        self.__dialog.set_sensitive(False)
-
-        net.post_file(target_uri=config.URI_UPLOADS,
-                      filename=lirc.find_remote_config()[0],
-                      content=self.__remote.configuration,
-                      context=_('customized configuration file'),
-                      finished_callback=on_upload_finished,
-                      failure_callback=on_upload_failure)
-
     def __retreive_remote_name(self):
         '''Build the symbolic name of the currently edited remote.'''
 
@@ -437,7 +379,9 @@ class CustomConfiguration(object):
         def report_failure(message):
             '''Handle failures reported by the service backend.'''
 
+            self.__detection_driver = None
             self.__progressbar_detect_basics.hide()
+            self.__button_detect_basics.set_sensitive(True)
             show_message(self.__dialog, _('Remote Configuration Failed'), message)
 
             if service:
@@ -447,7 +391,9 @@ class CustomConfiguration(object):
         def report_success(result, sender=None):
             '''Handle success reported by the service backend.'''
 
+            self.__detection_driver = None
             self.__progressbar_detect_basics.hide()
+            self.__button_detect_basics.set_sensitive(True)
 
             hwdb = lirc.RemotesDatabase()
             hwdb.read(StringIO(result))
@@ -511,6 +457,7 @@ class CustomConfiguration(object):
             self.__detection_driver = driver
             self.__detection_driver.Execute()
 
+            self.__button_detect_basics.set_sensitive(False)
             self.__progressbar_detect_basics.show()
 
         except dbus.DBusException, ex:
@@ -523,11 +470,14 @@ class CustomConfiguration(object):
         try:
             if self.__detection_driver:
                 self.__detection_driver.Release()
-                self.__detection_driver = None
 
         except dbus.DBusException, ex:
+            logging.error('Error running detection driver Release')
             logging.warning(ex)
 
+        self.__detection_driver = None
+
+
     def _on_dialog_changed(self, widget = None):
         '''Handle major changes to the dialog.'''
 
@@ -550,7 +500,6 @@ class CustomConfiguration(object):
 
         # Update state of model-page widgets:
         self.__usage_hint.set_property('visible', not model_complete)
-        self.__button_upload.set_sensitive(keys_complete)
 
         # Update state of basics-page widgets:
         self.__treeview_basics.set_sensitive(have_receiver)
@@ -689,9 +638,23 @@ class CustomConfiguration(object):
     def _on_response(self, dialog, response):
         '''Handle the dialog's "response" signal.'''
 
+        self.__stop_detection()
+        self.__stop_learning()
+
+        # Reset the progress back for detection
+        self.__progressbar_detect_basics.hide()
+        self.__button_detect_basics.set_sensitive(True)
+
         if gtk.RESPONSE_OK == response:
             try:
                 service = backend.get_service()
+
+                # Get the entered basic information, 
+                # so it will be written to the configuration file: 
+                self.__remote.contributor = self.contributor_name
+                self.__remote.vendor = self.vendor_name
+                self.__remote.product = self.product_name
+
                 self.__remote.update_configuration(service)
                 service.ManageLircDaemon('restart')
 
